==> haskell-bytestring-tree-builder-0.2.7.2-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-tree-builder
version: 0.2.7.2
id: bytestring-tree-builder-0.2.7.2-IoSrguA766I6Fph6Wtt5y1
key: bytestring-tree-builder-0.2.7.2-IoSrguA766I6Fph6Wtt5y1
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-tree-builder
synopsis: A very efficient ByteString builder implementation based on the binary tree
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.
category: ByteString
abi: 48e2c8fa91ffd5a2e24d2ab395f71e57
exposed: True
exposed-modules:
    ByteString.TreeBuilder
hidden-modules: ByteString.TreeBuilder.Prelude
                ByteString.TreeBuilder.Poker ByteString.TreeBuilder.Tree
import-dirs: /usr/lib/ghc-8.4.3/site-local/bytestring-tree-builder-0.2.7.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/bytestring-tree-builder-0.2.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/bytestring-tree-builder-0.2.7.2
hs-libraries: HSbytestring-tree-builder-0.2.7.2-IoSrguA766I6Fph6Wtt5y1
depends:
    bytestring-0.10.8.2 text-1.2.3.0
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7 base-4.11.1.0
abi-depends: bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-tree-builder-0.2.7.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-tree-builder
version: 0.2.7.2
id: bytestring-tree-builder-0.2.7.2-2Eqj6EocuPj6bnSV9xcPuW
key: bytestring-tree-builder-0.2.7.2-2Eqj6EocuPj6bnSV9xcPuW
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-tree-builder
synopsis: A very efficient ByteString builder implementation based on the binary tree
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.
category: ByteString
abi: dbefd5019dbb590383dca71eb8a9ed56
exposed: True
exposed-modules:
    ByteString.TreeBuilder
hidden-modules: ByteString.TreeBuilder.Prelude
                ByteString.TreeBuilder.Poker ByteString.TreeBuilder.Tree
import-dirs: /usr/lib/ghc-8.4.3/site-local/bytestring-tree-builder-0.2.7.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/bytestring-tree-builder-0.2.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/bytestring-tree-builder-0.2.7.2
hs-libraries: HSbytestring-tree-builder-0.2.7.2-2Eqj6EocuPj6bnSV9xcPuW
depends:
    bytestring-0.10.8.2 text-1.2.3.0
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7 base-4.11.1.0
abi-depends: bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
